@@ -1,11 +1,6 @@
 "PPT.AddTitleOnlySlide" <-function(ppt,title=NULL,title.fontsize=NULL,title.font=NULL){
 
-if(ppt$method=="rcom"){
 
-	if(!comIsValidHandle(ppt$ppt))   stop("Invalid handle for powerpoint application")
-	if(!comIsValidHandle(ppt$pres))  stop("Invalid handle for powerpoint presentation")
-
-}
 
 #ppt$Current.Slide <- comInvoke(comGetProperty(ppt$pres,"Slides"),"Add",comGetProperty(comGetProperty(ppt$pres,'Slides'),'Count')+1,11)
 ppt$Current.Slide<-ppt$pres[["Slides"]]$add(as.integer(max(1,ppt$pres[["Slides"]][["Count"]]+1)),as.integer(11))
