@@ -1,13 +1,10 @@
 "PPT.ApplyTemplate" <-function(ppt,file){
 
-if(ppt$method=="rcom"){
 
-	if(!comIsValidHandle(ppt$ppt))   stop("Invalid handle for powerpoint application")
-	if(!comIsValidHandle(ppt$pres))  stop("Invalid handle for powerpoint presentation")
 
-}
+#file<-PPT.getAbsolutePath(file[1]) #New in Version 1.1
+file[1]<-normalizePath(file[1]) #New in Version 2.2
 
-file<-PPT.getAbsolutePath(file[1]) #New in Version 1.1
 if(!file.exists(file)) stop(paste(file, "does not exist"))
 file<-gsub("/","\\\\",as.character(file))
 
